#!/usr/bin/env node
"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
Object.defineProperty(exports, "__esModule", { value: true });
var child_process = require("child_process");
var escape = require("escape-html");
var fs = require("fs");
var program = require("commander");
var utils_1 = require("./utils");
var temp = require('temp').track();
function list(val) {
    return val.split(',');
}
program
    .version('2.0.5')
    .usage('[options] /path/to/images/*.jpg')
    .option('-o, --output <file>', 'Path to output CSV file (default output.csv)', 'output.csv')
    .option('-l, --labels <csv>', 'Comma-separated list of choices of labels', list, ['Yes', 'No'])
    .option('-w, --max_width <pixels>', 'Make the images this width when displaying in-browser', parseInt)
    .parse(process.argv);
if (program.args.length == 0) {
    console.error('You must specify at least one image file!\n');
    program.help(); // exits
}
if (fs.existsSync(program.output)) {
    console.warn(utils_1.dedent(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n    Output file ", " already exists.\n    Its contents will be assumed to be previously-generated labels.\n    If you want to start from scratch, either delete this file,\n    rename it or specify a different output via --output"], ["\n    Output file ", " already exists.\n    Its contents will be assumed to be previously-generated labels.\n    If you want to start from scratch, either delete this file,\n    rename it or specify a different output via --output"])), program.output));
}
var csvInfo = temp.openSync({ suffix: '.csv' });
var templateInfo = temp.openSync({ suffix: '.html' });
fs.writeSync(csvInfo.fd, 'path\n' + program.args.join('\n') + '\n');
fs.closeSync(csvInfo.fd);
var buttonsHtml = program.labels.map(function (label, idx) {
    var buttonText = label + " (" + (1 + idx) + ")";
    return "<button type=\"submit\" data-key='" + (1 + idx) + "' name=\"label\" value=\"" + label + "\">" + escape(buttonText) + "</button>";
}).join('&nbsp;');
var widthHtml = program.max_width ? " width=\"" + program.max_width + "\"" : '';
var undoHtml = utils_1.dedent(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n    </form>\n    <form action=\"/delete-last\" method=\"POST\" style=\"display: inline-block\">\n      <input type=\"submit\" id=\"undo-button\" data-key=\"z\" value=\"Undo Last (z)\">\n    </form>"], ["\n    </form>\n    <form action=\"/delete-last\" method=\"POST\" style=\"display: inline-block\">\n      <input type=\"submit\" id=\"undo-button\" data-key=\"z\" value=\"Undo Last (z)\">\n    </form>"])));
var html = buttonsHtml + undoHtml + '\n<p><img src="${path}" ' + widthHtml + '></p>';
// Add keyboard shortcuts. 1=first button, etc.
html += utils_1.dedent(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n    <style>\n      form { display: inline-block; }\n      #undo-button { margin-left: 20px; }\n    </style>"], ["\n    <style>\n      form { display: inline-block; }\n      #undo-button { margin-left: 20px; }\n    </style>"])));
fs.writeSync(templateInfo.fd, html);
fs.closeSync(templateInfo.fd);
var args = ['localturk', '--static-dir', '.', templateInfo.path, csvInfo.path, program.output];
console.log('Running ', args.join(' '));
child_process.spawn(args[0], args.slice(1), { stdio: 'inherit' });
var templateObject_1, templateObject_2, templateObject_3;
